@@ -8,11 +8,13 @@ from scipy import stats
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
+import matplotlib.cm as cm
 import torch
 tf.io.gfile = tb.compat.tensorflow_stub.io.gfile
 from captum.attr import IntegratedGradients, FeaturePermutation
 from captum.attr import visualization as viz
 from captum.attr import GuidedGradCam, LayerGradCam, LayerAttribution
+from PIL import Image
 
 
 class ComprehensibilityAnalysis:
@@ -221,20 +223,27 @@ class ComprehensibilityAnalysis:
         plt.title('original image')
         plt.show()
 
-    def grad_cam(self, layer, img_index, guided=False):
+    def grad_cam(self, layer, img_index, class_labels):
         "Grad Cam requires PyTorch and CNNs"
         y_test = self.interface.from_numpy(self.y_test, dtype=torch.int64)
         x_test = self.x_test.requires_grad_()
-        if guided:
-            gradcam = GuidedGradCam(self.model, layer)
-            attr = gradcam.attribute(x_test, y_test[img_index])
-        else:
-            gradcam = LayerGradCam(self.model, self.model.conv2)
-            attr = gradcam.attribute(x_test, y_test[img_index], relu_attributions=True)
-        print(self.x_test.shape)
-        print(self.x_test.shape[-2:])
-        upsampled_attr = LayerAttribution.interpolate(attr, self.x_test.shape[-2:])
+        gradcam = LayerGradCam(self.model, layer)
+        attr = gradcam.attribute(x_test, y_test[img_index], relu_attributions=True)
+        upsampled_attr = LayerAttribution.interpolate(attr, self.x_test.shape[-2:], interpolate_mode='bilinear')
+        upsampled_attr = upsampled_attr.detach().numpy()
+        masked_data = np.ma.masked_where(upsampled_attr < 0.001, upsampled_attr)
         org_image = x_test.detach().numpy().transpose(0, 2, 3, 1)
         plt.imshow(org_image[img_index, ...])
-        plt.imshow(upsampled_attr.detach().numpy()[img_index, 0, :, :], cmap='hot', alpha=0.2)
+        plt.imshow(masked_data[img_index, 0, :, :], cmap='rainbow', alpha=0.5)
+        plt.title('Gradient overlayed with image')
+
+        output = self.model(x_test)
+        output_top_5 = torch.argsort(output[0], descending=True)[:5]
+        output_top_5 = [i.item() for i in output_top_5]
+        plt.xlabel(f"Top 5 classes:\n"
+                   f"{class_labels[output_top_5[0]]}\n"
+                   f"{class_labels[output_top_5[1]]}\n"
+                   f"{class_labels[output_top_5[2]]}\n"
+                   f"{class_labels[output_top_5[3]]}\n"
+                   f"{class_labels[output_top_5[4]]}\n")
         plt.show()
\ No newline at end of file
