@@ -37,13 +37,13 @@ from PIL import Image
 # Tensorflow
 import tensorflow as tf
 
+print(tf.__version__)
 
 def main(params):
     # pytorch_titanic()
     # pytorch_cifar()
     pytorch_imagenet()
     # scikit()
-    # tensorflow()
     # tensorflow_titanic()
 
 
@@ -107,18 +107,18 @@ def pytorch_cifar():
                                          example=example, classes=classes)
     analysis = ComprehensibilityAnalysis(interface)
     analysis.integrated_gradients(img_index=9)
-    analysis.grad_cam(model.conv2, img_index=example)
+    analysis.grad_cam(model.conv2, img_index=example, class_labels=classes)
 
-    # classifier = PyTorchClassifier(
-    #     model=model,
-    #     loss=criterion,
-    #     input_shape=x_test.shape[1:],
-    #     nb_classes=10,
-    # )
-    # x_test = x_test.detach().numpy()
-    # metric = empirical_robustness(classifier, x_test, attack_name='hsj',
-    #                               attack_params={'max_iter': 10, 'max_eval': 10, 'init_eval': 2})
-    # print(metric)
+    classifier = PyTorchClassifier(
+        model=model,
+        loss=criterion,
+        input_shape=x_test.shape[1:],
+        nb_classes=10,
+    )
+    x_test = x_test.detach().numpy()
+    metric = empirical_robustness(classifier, x_test, attack_name='fgsm',
+                                  attack_params={'max_iter': 10, 'max_eval': 10, 'init_eval': 2})
+    print(metric)
 
 
 def pytorch_imagenet():
@@ -136,13 +136,27 @@ def pytorch_imagenet():
     x_test = transform(image)
     x_test = x_test.unsqueeze(0)
     y_test = torch.tensor(217).unsqueeze(0)
-
+    print(x_test.shape)
     interface = PyTorchInterface(alexnet, x_test, y_test, metric_name='accuracy')
     comprehensibility = ComprehensibilityAnalysis(interface)
     # print(alexnet.features[10])
     comprehensibility.integrated_gradients(0)
     comprehensibility.grad_cam(alexnet.features[10], 0, class_labels=class_labels)
+    criterion = nn.CrossEntropyLoss()
+    robustness = RobustnessAnalysis(interface)
+    robustness.fast_gradient_sign_method(num_classes=1000, criterion=criterion, visualize=True, eps=0.05,
+                                         example=0, classes=class_labels)
 
+    # classifier = PyTorchClassifier(
+    #         model=alexnet,
+    #         loss=criterion,
+    #         input_shape=x_test.shape[1:],
+    #         nb_classes=10,
+    #     )
+    # x_test = x_test.detach().numpy()
+    # metric = empirical_robustness(classifier, x_test, attack_name='fgsm',
+    #                               attack_params={'max_iter': 10, 'max_eval': 10, 'init_eval': 2})
+    # print(metric)
 
 
 
@@ -167,33 +181,6 @@ def scikit():
     # analysis.vis_pca_tb(dataset=True, vis_imgs_tb=False)
 
 
-def tensorflow():
-    num = 100
-    mnist = tf.keras.datasets.mnist
-    (x_train, y_train), (x_test, y_test) = mnist.load_data()
-    x_train, x_test = x_train / 255.0, x_test / 255.0
-    model = tf.keras.models.Sequential([
-      tf.keras.layers.Flatten(input_shape=(28, 28)),
-      tf.keras.layers.Dense(128, activation='relu'),
-      tf.keras.layers.Dropout(0.2),
-      tf.keras.layers.Dense(10)
-    ])
-    loss_fn = tf.keras.losses.SparseCategoricalCrossentropy(from_logits=True)
-    model.compile(optimizer='adam',
-                  loss=loss_fn,
-                  metrics=['accuracy'])
-
-    model.fit(x_train, y_train, epochs=1)
-    y_pred_raw = model(x_test[:num])
-    y_pred = tf.math.argmax(y_pred_raw, axis=1)
-    function = model.layers[3]
-
-    interface = TensorFlowInterface(model, x_test[:num], y_test[:num], y_pred)
-    analysis = ComprehensibilityAnalysis(interface)
-    analysis.visualize_pca(function=function, n_components=4)
-    analysis.vis_pca_tb(function=function, vis_imgs_tb=False)
-
-
 def tensorflow_titanic():
     titanic_data = pd.read_csv('titanic.csv', index_col=0)
     labels = titanic_data["survived"]
